@@ -290,16 +290,17 @@ If no FILE or if FILE is `-', read standard input.\n\
 \n\
 Mandatory arguments to long options are mandatory for short options too.\n\
   -c, --crown-margin        preserve indentation of first two lines\n\
+  -p, --prefix=STRING       combine only lines having STRING as prefix\n\
   -s, --split-only          split long lines, but do not refill\n\
   -t, --tagged-paragraph    indentation of first line different from second\n\
   -u, --uniform-spacing     one space between words, two after sentences\n\
   -w, --width=NUMBER        maximum line width (default of 75 columns)\n\
-  -p, --prefix=STRING       combine only lines having STRING as prefix\n\
       --help                display this help and exit\n\
       --version             output version information and exit\n\
 \n\
 In -wNUMBER, the letter `w' may be omitted.\n"),
 	     stdout);
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -397,7 +398,7 @@ main (register int argc, register char **argv)
 
   if (show_version)
     {
-      printf ("fmt - %s\n", PACKAGE_VERSION);
+      printf ("fmt (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
@@ -630,7 +631,7 @@ get_line (FILE *f, register int c)
 	  *wptr++ = c;
 	  c = getc (f);
 	}
-      while (c != EOF && !isspace (c));
+      while (c != EOF && !ISSPACE (c));
       in_column += word_limit->length = wptr - word_limit->text;
       check_punctuation (word_limit);
 
@@ -714,7 +715,7 @@ check_punctuation (register WORD *w)
   start = w->text;
   finish = start + (w->length - 1);
   w->paren = isopen (*start);
-  w->punct = ispunct (*finish);
+  w->punct = ISPUNCT (*finish);
   while (isclose (*finish) && finish > start)
     finish--;
   w->period = isperiod (*finish);
