@@ -177,19 +177,19 @@ For each pair of input lines with identical join fields, write a line to\n\
 standard output.  The default join field is the first, delimited\n\
 by whitespace.  When FILE1 or FILE2 (not both) is -, read standard input.\n\
 \n\
-  -a SIDE          print unpairable lines coming from file SIDE\n\
-  -e EMPTY         replace missing input fields with EMPTY\n\
+  -a SIDE           print unpairable lines coming from file SIDE\n\
+  -e EMPTY          replace missing input fields with EMPTY\n\
   -i, --ignore-case ignore differences in case when comparing fields\n\
-  -j FIELD         (Obsolescent) equivalent to `-1 FIELD -2 FIELD'\n\
-  -j1 FIELD        (Obsolescent) equivalent to `-1 FIELD'\n\
-  -j2 FIELD        (Obsolescent) equivalent to `-2 FIELD'\n\
-  -1 FIELD         join on this FIELD of file 1\n\
-  -2 FIELD         join on this FIELD of file 2\n\
-  -o FORMAT        obey FORMAT while constructing output line\n\
-  -t CHAR          use CHAR as input and output field separator\n\
-  -v SIDE          like -a SIDE, but suppress joined output lines\n\
-  --help           display this help and exit\n\
-  --version        output version information and exit\n\
+  -j FIELD          (obsolescent) equivalent to `-1 FIELD -2 FIELD'\n\
+  -j1 FIELD         (obsolescent) equivalent to `-1 FIELD'\n\
+  -j2 FIELD         (obsolescent) equivalent to `-2 FIELD'\n\
+  -o FORMAT         obey FORMAT while constructing output line\n\
+  -t CHAR           use CHAR as input and output field separator\n\
+  -v SIDE           like -a SIDE, but suppress joined output lines\n\
+  -1 FIELD          join on this FIELD of file 1\n\
+  -2 FIELD          join on this FIELD of file 2\n\
+      --help        display this help and exit\n\
+      --version     output version information and exit\n\
 \n\
 Unless -t CHAR is given, leading blanks separate fields and are ignored,\n\
 else fields are separated by CHAR.  Any FIELD is a field number counted\n\
@@ -198,6 +198,7 @@ each being `SIDE.FIELD' or `0'.  Default FORMAT outputs the join field,\n\
 the remaining fields from FILE1, the remaining fields from FILE2, all\n\
 separated by CHAR.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -459,6 +460,7 @@ prjoin (struct line *line1, struct line *line2)
 	  else
 	    {
 	      line = (o->file == 1 ? line1 : line2);
+	      assert (o->field >= 0);
 	      field = o->field;
 	    }
 	  prfield (field, line);
@@ -629,7 +631,7 @@ add_field (int file, int field)
   struct outlist *o;
 
   assert (file == 0 || file == 1 || file == 2);
-  assert (field >= 0);
+  assert (file == 0 ? field < 0 : field >= 0);
 
   o = (struct outlist *) xmalloc (sizeof (struct outlist));
   o->file = file;
@@ -658,7 +660,8 @@ decode_field_spec (const char *s, int *file_index, int *field_index)
       if (s[1] == '\0')
 	{
 	  *file_index = 0;
-	  /* Leave *field_index undefined.  */
+	  /* Give *field_index an invalid value.  */
+	  *field_index = -1;
 	  invalid = 0;
 	}
       else
@@ -764,7 +767,7 @@ main (int argc, char **argv)
      it may be increased.  */
   uni_blank.nfields = 1;
 
-  parse_long_options (argc, argv, "join", PACKAGE_VERSION, usage);
+  parse_long_options (argc, argv, "join", GNU_PACKAGE, VERSION, usage);
 
   nfiles = 0;
   print_pairables = 1;
