@@ -84,10 +84,6 @@ typedef double LONG_DOUBLE;
 # define BITSPERBYTE 8
 #endif
 
-#ifndef OFF_T_MAX
-# define OFF_T_MAX ((off_t)(~((off_t)1 << (sizeof (off_t) * BITSPERBYTE - 1))))
-#endif
-
 #define STREQ(a,b) (strcmp((a), (b)) == 0)
 
 #ifndef MAX
@@ -342,8 +338,8 @@ Write an unambiguous representation, octal bytes by default, of FILE\n\
 to standard output.  With no FILE, or when FILE is -, read standard input.\n\
 \n\
   -A, --address-radix=RADIX   decide how file offsets are printed\n\
-  -N, --read-bytes=BYTES      limit dump to BYTES input bytes per file\n\
   -j, --skip-bytes=BYTES      skip BYTES input bytes first on each file\n\
+  -N, --read-bytes=BYTES      limit dump to BYTES input bytes per file\n\
   -s, --strings[=BYTES]       output strings of at least BYTES graphic chars\n\
   -t, --format=TYPE           select output format or formats\n\
   -v, --output-duplicates     do not use * to mark line suppression\n\
@@ -392,6 +388,7 @@ with b suffix, by 1024 with k and by 1048576 with m.  -s without a\n\
 number implies 3.  -w without a number implies 32.  By default, od\n\
 uses -A o -t d2 -w 16.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -1714,10 +1711,10 @@ it must be one character from [doxn]"),
 	  if (s_err != LONGINT_OK)
 	    STRTOL_FATAL_ERROR (optarg, _("limit argument"), s_err);
 
-	  if (tmp > OFF_T_MAX)
+	  if (tmp > LONG_MAX)
 	    error (EXIT_FAILURE, 0,
 		   _("specified number of bytes `%s' is larger than \
-the maximum\nrepresentable value of type off_t"), optarg);
+the maximum\nrepresentable value of type `long'"), optarg);
 	  break;
 
 	case 's':
@@ -1796,7 +1793,7 @@ the maximum\nrepresentable value of type off_t"), optarg);
 
   if (show_version)
     {
-      printf ("od - %s\n", PACKAGE_VERSION);
+      printf ("od (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
