@@ -457,13 +457,13 @@ static int input_position;
    status if there were any.  */
 static int failed_opens = 0;
 
-/* The horizontal position we'll be at after printing a tab character
-   of width c_ from the position h_. */
-#define pos_after_tab(c_, h_) h_ - h_ % c_ + c_
-
 /* The number of spaces taken up if we print a tab character with width
    c_ from position h_. */
-#define tab_width(c_, h_) - h_ % c_ + c_
+#define TAB_WIDTH(c_, h_) ((c_) - ((h_) % (c_)))
+
+/* The horizontal position we'll be at after printing a tab character
+   of width c_ from the position h_. */
+#define POS_AFTER_TAB(c_, h_) ((h_) + TAB_WIDTH (c_, h_))
 
 /* (-NNN) Number of columns of text to print. */
 static int columns = 1;
@@ -996,7 +996,7 @@ init_parameters (int number_of_files)
       if (number_separator == input_tab_char)
 	{
 	  number_width = chars_per_number +
-	    tab_width (chars_per_input_tab,
+	    TAB_WIDTH (chars_per_input_tab,
 		       (chars_per_margin + chars_per_number));
 	}
       else
@@ -1076,6 +1076,7 @@ init_fps (int number_of_files, char **av)
 	  if (open_file (*av, p) == 0)
 	    return 1;
 	  init_header (*av, fileno (p->fp));
+	  p->lines_stored = 0;
 	}
       else
 	{
@@ -1086,6 +1087,7 @@ init_fps (int number_of_files, char **av)
 	  p->full_page_printed = FALSE;
 	  ++total_files;
 	  init_header ("", -1);
+	  p->lines_stored = 0;
 	}
 
       firstname = p->name;
@@ -1096,6 +1098,7 @@ init_fps (int number_of_files, char **av)
 	  p->fp = firstfp;
 	  p->status = OPEN;
 	  p->full_page_printed = FALSE;
+	  p->lines_stored = 0;
 	}
     }
   files_ready_to_read = total_files;
@@ -1360,7 +1363,7 @@ init_header (char *filename, int desc)
   int chars_per_middle, chars_free, lhs_blanks, rhs_blanks;
   char *f = filename;
   char *no_middle = "";
-  char *header_text, *t_buf;
+  char *header_text;
   struct tm *tmptr;
   struct stat st;
   char *datim = "- Date/Time --";
@@ -1376,18 +1379,16 @@ init_header (char *filename, int desc)
     sprintf (header, "%s", " ");	/* blank line header */
   else
     {
+#define T_BUF_FMT "%y-%m-%d %H:%M"	/* date/time short format */
+#define T_BUF_SIZE 15
+      char t_buf[T_BUF_SIZE];
+
       /* If parallel files or standard input, use current time. */
       if (desc < 0 || !strcmp (filename, "-") || fstat (desc, &st))
 	st.st_mtime = time (NULL);
 
-      {
-	size_t t_buf_size = 15;
-	const char *fmt = "%y-%m-%d %H:%M";	/* date/time short format */
-
-	t_buf = (char *) xmalloc (t_buf_size);
-	tmptr = localtime (&st.st_mtime);
-	strftime (t_buf, t_buf_size, fmt, tmptr);
-      }
+      tmptr = localtime (&st.st_mtime);
+      strftime (t_buf, T_BUF_SIZE, T_BUF_FMT, tmptr);
 
       chars_per_middle = chars_per_line - CHARS_FOR_DATE_AND_PAGE;
       if (chars_per_middle < 3)
@@ -1643,6 +1644,7 @@ init_store_cols (void)
 
   if (line_vector != NULL)
     free ((int *) line_vector);
+  /* FIXME: here's where it was allocated.  */
   line_vector = (int *) xmalloc ((total_lines + 1) * sizeof (int *));
 
   if (end_vector != NULL)
@@ -1927,7 +1929,7 @@ print_white_space (void)
   register int goal = h_old + spaces_not_printed;
 
   while (goal - h_old > 1
-	 && (h_new = pos_after_tab (chars_per_output_tab, h_old)) <= goal)
+	 && (h_new = POS_AFTER_TAB (chars_per_output_tab, h_old)) <= goal)
     {
       putchar (output_tab_char);
       h_old = h_new;
@@ -2234,6 +2236,17 @@ print_stored (COLUMN *p)
 
   int line = p->current_line++;
   register char *first = &buff[line_vector[line]];
+  /* FIXME
+     UMR: Uninitialized memory read:
+     * This is occurring while in:
+     print_stored   [pr.c:2239]
+     * Reading 4 bytes from 0x5148c in the heap.
+     * Address 0x5148c is 4 bytes into a malloc'd block at 0x51488 of 676 bytes
+     * This block was allocated from:
+     malloc         [rtlib.o]
+     xmalloc        [xmalloc.c:94]
+     init_store_cols [pr.c:1648]
+     */
   register char *last = &buff[line_vector[line + 1]];
 
   pad_vertically = TRUE;
@@ -2298,7 +2311,7 @@ char_to_clump (int c)
 
   if (c == input_tab_char)
     {
-      width = tab_width (chars_per_input_tab, input_position);
+      width = TAB_WIDTH (chars_per_input_tab, input_position);
 
       if (untabify_input)
 	{
@@ -2427,7 +2440,8 @@ Paginate or columnate FILE(s) for printing.\n\
   -j                merge full lines, turns off -w line truncation, no column\n\
                     alignment, -s[STRING] sets separators\n\
   -l PAGE_LENGTH    set the page length to PAGE_LENGTH (66) lines\n\
-                    (default number of lines of text 56, with -f 63)\n\
+                    (default number of lines of text 56, with -f 63)\n"));
+      printf (_("\
   -m                print all files in parallel, one in each column,\n\
                     truncate lines, but join lines of full length with -j\n\
   -n[SEP[DIGITS]]   number lines, use DIGITS (5) digits, then SEP (TAB)\n\
