@@ -134,6 +134,7 @@ standard input), writing to OUTPUT (or standard output).\n\
 A field is a run of whitespace, than non-whitespace characters.\n\
 Fields are skipped before chars.\n\
 "));
+      puts (_("\nReport bugs to textutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -383,7 +384,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("uniq - %s\n", PACKAGE_VERSION);
+      printf ("uniq (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (EXIT_SUCCESS);
     }
 
